@@ -1,3 +1,5 @@
+"""Univariate selection function."""
+
 import numpy as np
 from scipy.stats import kstest
 
@@ -27,7 +29,7 @@ def select_univariate(X, candidates):
             if ks < best_ks:
                 best_ks = ks
                 best_model = model
-        except ValueError:
+        except Exception:
             # Distribution not supported
             pass
 
