@@ -60,7 +60,8 @@ class TestGaussian(TestCase):
 
         # Test CDF
         cdf = model.cumulative_distribution(sampled_data)
-        assert (0 <= cdf).all() and (cdf <= 1).all()
+        assert (0 <= cdf).all()
+        assert (cdf <= 1).all()
 
         # Test CDF increasing function
         sorted_data = sorted(sampled_data)
@@ -84,6 +85,24 @@ class TestGaussian(TestCase):
         cdf2 = model2.cumulative_distribution(sampled_data)
         assert np.all(np.isclose(cdf, cdf2, atol=0.01))
 
+    def test_to_dict_from_dict_constant(self):
+        model = GaussianUnivariate()
+        model.fit(self.constant)
+
+        sampled_data = model.sample(50)
+        pdf = model.probability_density(sampled_data)
+        cdf = model.cumulative_distribution(sampled_data)
+
+        params = model.to_dict()
+        model2 = GaussianUnivariate.from_dict(params)
+
+        np.testing.assert_equal(np.full(50, 5), sampled_data)
+        np.testing.assert_equal(np.full(50, 5), model2.sample(50))
+        np.testing.assert_equal(np.full(50, 1), pdf)
+        np.testing.assert_equal(np.full(50, 1), model2.probability_density(sampled_data))
+        np.testing.assert_equal(np.full(50, 1), cdf)
+        np.testing.assert_equal(np.full(50, 1), model2.cumulative_distribution(sampled_data))
+
     def test_to_dict_constant(self):
         model = GaussianUnivariate()
         model.fit(self.constant)
@@ -102,7 +121,7 @@ class TestGaussian(TestCase):
 
         sampled_data = model.sample(50)
 
-        path_to_model = os.path.join(self.test_dir.name, "model.pkl")
+        path_to_model = os.path.join(self.test_dir.name, 'model.pkl')
         model.save(path_to_model)
         model2 = GaussianUnivariate.load(path_to_model)
 
@@ -113,3 +132,26 @@ class TestGaussian(TestCase):
         cdf = model.cumulative_distribution(sampled_data)
         cdf2 = model2.cumulative_distribution(sampled_data)
         assert np.all(np.isclose(cdf, cdf2, atol=0.01))
+
+    def test_fixed_random_state(self):
+        """Test that the univariate models work with a fixed seed.
+        Expect that fixing the seed generates a reproducable sequence
+        of samples. Expect that these samples are different from randomly
+        sampled results.
+        """
+        model = GaussianUnivariate()
+        model.fit(self.data)
+
+        sampled_random = model.sample(10)
+        model.set_random_state(0)
+        sampled_0_0 = model.sample(10)
+        sampled_0_1 = model.sample(10)
+
+        model.set_random_state(0)
+        sampled_1_0 = model.sample(10)
+        sampled_1_1 = model.sample(10)
+
+        assert not np.array_equal(sampled_random, sampled_0_0)
+        assert not np.array_equal(sampled_0_0, sampled_0_1)
+        np.testing.assert_array_equal(sampled_0_0, sampled_1_0)
+        np.testing.assert_array_equal(sampled_0_1, sampled_1_1)
