@@ -19,7 +19,7 @@ class TestGaussian(TestCase):
         self.test_dir.cleanup()
 
     def test_fit_sample(self):
-        model = TruncatedGaussian(min=1, max=5)
+        model = TruncatedGaussian(minimum=1, maximum=5)
         model.fit(self.data)
 
         np.testing.assert_allclose(model._params['loc'], 1.0, atol=0.2)
@@ -62,7 +62,8 @@ class TestGaussian(TestCase):
 
         # Test the CDF
         cdf = model.cumulative_distribution(sampled_data)
-        assert (0 <= cdf).all() and (cdf <= 1).all()
+        assert (0 <= cdf).all()
+        assert (cdf <= 1).all()
 
         # Test CDF increasing function
         sorted_data = sorted(sampled_data)
@@ -105,7 +106,7 @@ class TestGaussian(TestCase):
         np.testing.assert_equal(np.full(50, 1), model2.cumulative_distribution(sampled_data))
 
     def test_to_dict_constant(self):
-        model = TruncatedGaussian(min=1, max=5)
+        model = TruncatedGaussian(minimum=1, maximum=5)
         model.fit(self.constant)
 
         params = model.to_dict()
@@ -124,7 +125,7 @@ class TestGaussian(TestCase):
 
         sampled_data = model.sample(50)
 
-        path_to_model = os.path.join(self.test_dir.name, "model.pkl")
+        path_to_model = os.path.join(self.test_dir.name, 'model.pkl')
         model.save(path_to_model)
         model2 = TruncatedGaussian.load(path_to_model)
 
@@ -135,3 +136,26 @@ class TestGaussian(TestCase):
         cdf = model.cumulative_distribution(sampled_data)
         cdf2 = model2.cumulative_distribution(sampled_data)
         assert np.all(np.isclose(cdf, cdf2, atol=0.01))
+
+    def test_fixed_random_state(self):
+        """Test that the univariate models work with a fixed seed.
+        Expect that fixing the seed generates a reproducable sequence
+        of samples. Expect that these samples are different from randomly
+        sampled results.
+        """
+        model = TruncatedGaussian()
+        model.fit(self.data)
+
+        sampled_random = model.sample(10)
+        model.set_random_state(0)
+        sampled_0_0 = model.sample(10)
+        sampled_0_1 = model.sample(10)
+
+        model.set_random_state(0)
+        sampled_1_0 = model.sample(10)
+        sampled_1_1 = model.sample(10)
+
+        assert not np.array_equal(sampled_random, sampled_0_0)
+        assert not np.array_equal(sampled_0_0, sampled_0_1)
+        np.testing.assert_array_equal(sampled_0_0, sampled_1_0)
+        np.testing.assert_array_equal(sampled_0_1, sampled_1_1)
